@@ -1,9 +1,9 @@
 package Net::DNS::SEC::DSA;
 
-#
-# $Id: DSA.pm 1763 2020-02-02 21:48:03Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1763 $)[1];
+use strict;
+use warnings;
+
+our $VERSION = (qw$Id: DSA.pm 1853 2021-10-11 10:40:59Z willem $)[2];
 
 
 =head1 NAME
@@ -41,22 +41,20 @@ public key resource record.
 
 =cut
 
-use strict;
 use integer;
-use warnings;
 use MIME::Base64;
 
-use constant DSA_configured => Net::DNS::SEC::libcrypto->can('EVP_PKEY_assign_DSA');
+use constant DSA_configured => Net::DNS::SEC::libcrypto->can('EVP_PKEY_new_DSA');
 
 BEGIN { die 'DSA disabled or application has no "use Net::DNS::SEC"' unless DSA_configured }
 
 
 my %parameters = (
-	3 => sub { Net::DNS::SEC::libcrypto::EVP_sha1() },
-	6 => sub { Net::DNS::SEC::libcrypto::EVP_sha1() },
+	3 => Net::DNS::SEC::libcrypto::EVP_sha1(),
+	6 => Net::DNS::SEC::libcrypto::EVP_sha1(),
 	);
 
-sub _index { keys %parameters }
+sub _index { return keys %parameters }
 
 
 sub sign {
@@ -65,19 +63,14 @@ sub sign {
 	my $index = $private->algorithm;
 	my $evpmd = $parameters{$index} || die 'private key not DSA';
 
-	my ( $p, $q, $g, $x, $y ) = map decode_base64( $private->$_ ),
-			qw(prime subprime base private_value public_value);
+	my ( $p, $q, $g, $x, $y ) =
+			map { decode_base64( $private->$_ ) } qw(prime subprime base private_value public_value);
 	my $t = ( length($g) - 64 ) / 8;
 
-	my $dsa = Net::DNS::SEC::libcrypto::DSA_new();
-	Net::DNS::SEC::libcrypto::DSA_set0_pqg( $dsa, $p, $q, $g );
-	Net::DNS::SEC::libcrypto::DSA_set0_key( $dsa, $y, $x );
+	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new_DSA( $p, $q, $g, $y, $x );
 
-	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new();
-	Net::DNS::SEC::libcrypto::EVP_PKEY_assign_DSA( $evpkey, $dsa );
-
-	my $asn1 = Net::DNS::SEC::libcrypto::EVP_sign( $sigdata, $evpkey, &$evpmd );
-	_ASN1decode( $asn1, $t );
+	my $asn1 = Net::DNS::SEC::libcrypto::EVP_sign( $sigdata, $evpkey, $evpmd );
+	return _ASN1decode( $asn1, $t );
 }
 
 
@@ -93,15 +86,10 @@ sub verify {
 	my $len = 64 + 8 * unpack( 'C', $key );			# RFC2536, section 2
 	my ( $q, $p, $g, $y ) = unpack "x a20 a$len a$len a$len", $key;
 
-	my $dsa = Net::DNS::SEC::libcrypto::DSA_new();
-	Net::DNS::SEC::libcrypto::DSA_set0_pqg( $dsa, $p, $q, $g );
-	Net::DNS::SEC::libcrypto::DSA_set0_key( $dsa, $y, '' );
-
-	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new();
-	Net::DNS::SEC::libcrypto::EVP_PKEY_assign_DSA( $evpkey, $dsa );
+	my $evpkey = Net::DNS::SEC::libcrypto::EVP_PKEY_new_DSA( $p, $q, $g, $y, '' );
 
 	my $asn1 = _ASN1encode($sigbin);
-	Net::DNS::SEC::libcrypto::EVP_verify( $sigdata, $asn1, $evpkey, &$evpmd );
+	return Net::DNS::SEC::libcrypto::EVP_verify( $sigdata, $asn1, $evpkey, $evpmd );
 }
 
 
@@ -117,7 +105,7 @@ sub _ASN1encode {
 		$_ = pack 'C2 a*', 2, length, $_;
 		$length += length;
 	}
-	pack 'C2 a* a*', 0x30, $length, @part;
+	return pack 'C2 a* a*', 0x30, $length, @part;
 }
 
 sub _ASN1decode {
@@ -125,7 +113,7 @@ sub _ASN1decode {
 	my $n	 = unpack 'x3 C',	   $asn1;
 	my $m	 = unpack "x5 x$n C",	   $asn1;
 	my @part = unpack "x4 a$n x2 a$m", $asn1;
-	pack 'C a* a*', $t, map substr( pack( 'x20 a*', $_ ), -20 ), @part;
+	return pack 'C a* a*', $t, map { substr( pack( 'x20 a*', $_ ), -20 ) } @part;
 }
 
 
@@ -152,7 +140,7 @@ All rights reserved.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
