@@ -1,9 +1,9 @@
 package Net::DNS::SEC::ECCGOST;
 
-#
-# $Id: ECCGOST.pm 1723 2018-12-03 09:17:48Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1723 $)[1];
+use strict;
+use warnings;
+
+our $VERSION = (qw$Id: ECCGOST.pm 1853 2021-10-11 10:40:59Z willem $)[2];
 
 
 =head1 NAME
@@ -37,19 +37,15 @@ public key resource record.
 =cut
 
 
-use strict;
-use integer;
-use warnings;
-
-use constant ECCGOST_configured => Net::DNS::SEC::libcrypto->can('ECCGOST_verify');
-
-BEGIN { die 'No "use Net::DNS::SEC" or no ECCGOST' unless ECCGOST_configured }
-
-BEGIN { require Digest::GOST::CryptoPro }
+use constant Digest_GOST	=> defined( eval { require Digest::GOST } );
+use constant ECCGOST_configured => Digest_GOST && Net::DNS::SEC::libcrypto->can('ECCGOST_verify');
 
+BEGIN { die 'ECCGOST disabled or application has no "use Net::DNS::SEC"' unless ECCGOST_configured }
 
 my %parameters = ( 12 => [840, 'Digest::GOST::CryptoPro'] );
 
+sub _index { return keys %parameters }
+
 
 sub sign {
 	die 'Russian Federation standard GOST R 34.10-2001 is obsolete';
@@ -68,12 +64,11 @@ sub verify {
 
 	return unless $sigbin;
 
-	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_new_ECCGOST();
 	my ( $y, $x ) = unpack 'a32 a32', reverse $keyrr->keybin;    # public key
-	Net::DNS::SEC::libcrypto::EC_KEY_set_public_key_affine_coordinates( $eckey, $x, $y );
+	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_new_ECCGOST( $x, $y );
 
 	my ( $s, $r ) = unpack 'a32 a32', $sigbin;		# RFC5933, RFC4490
-	Net::DNS::SEC::libcrypto::ECCGOST_verify( $H, $r, $s, $eckey );
+	return Net::DNS::SEC::libcrypto::ECCGOST_verify( $H, $r, $s, $eckey );
 }
 
 
@@ -94,7 +89,7 @@ All rights reserved.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
